@@ -12,7 +12,6 @@ OC.L10N.register(
     "Group name" : "Nombre del grupo",
     "Rename" : "Renombrar",
     "Enabled" : "Habilitado",
-    "Disabled" : "Deshabilitado",
     "Delete" : "Borrar",
     "Copied" : "Copiado",
     "Copy link" : "Copiar enlace",
@@ -20,7 +19,6 @@ OC.L10N.register(
     "No users or groups" : "No hay usuarios ni grupos.",
     "can edit" : "poder editar",
     "Importing is disabled because there are no address books available" : "La importación está deshabilitada porque no hay libretas de direcciones disponibles",
-    "Address book name" : "Nombre de la libreta de direcciones",
     "First name" : "Nombre",
     "Last name" : "Apellido",
     "Display name" : "Nombre para mostrar",
@@ -110,7 +108,6 @@ OC.L10N.register(
     "Female" : "Femenino",
     "Male" : "Masculino",
     "None" : "Ninguno",
-    "Unknown" : "Desconocido",
-    "Timezone" : "Zona horaria"
+    "Unknown" : "Desconocido"
 },
 "nplurals=2; plural=(n != 1);");
