@@ -10,13 +10,11 @@ OC.L10N.register(
     "Group name" : "Grupi nimi",
     "Rename" : "Nimeta ümber",
     "Enabled" : "Lubatud",
-    "Disabled" : "Keelatud",
     "Delete" : "Kustuta",
     "Copy link" : "Kopeeri link",
     "Share with users or groups" : "Jaga kasutajate või gruppidega",
     "No users or groups" : "Ei ole kasutajaid või gruppe",
     "can edit" : "saab redigeerida",
-    "Address book name" : "Aadressiraamatu nimi",
     "First name" : "Eesnimi",
     "Last name" : "Perekonnanimi",
     "Display name" : "Kuvatav nimi",
