@@ -8,25 +8,44 @@ OC.L10N.register(
     "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Nextcloud の連絡先アプリは、 Nextcloud の CardDAV サーバーのユーザーインターフェースです。 さまざまなデバイスの連絡先を Nextcloud で簡単に同期し、オンラインで編集できます。\n\n*🚀**他の Nextcloud アプリケーションとの統合！**現在、メールとカレンダー - 今後の予定です。\n*🎉**誕生日を忘れないでください！**あなたの Nextcloud カレンダーで誕生日やその他の定期的なイベントを同期できます。\n*👥** 連絡先の共有！**あなたの友達や同僚とあなたの連絡先を共有したいですか？ 問題ない！\n*🙈**私たちは車輪を再発明していません！**偉大でオープンな SabreDAV ライブラリをベースにしています。",
     "Copy to full name" : "フルネームをコピー",
     "Omit year" : "年を省略する",
+    "Allow updating avatars from social media" : "ソーシャルメディアからのアバターの更新を許可する",
+    "Please select a circle" : "サークルを選択",
+    "Loading circle …" : "サークルを読み込み中...",
+    "Your request to join this circle is pending approval" : "このサークルへの参加リクエストは承認待ちです",
+    "You are not a member of {circle}" : "あなたはサークル{circle}のメンバーではありません",
+    "There was an error fetching the member list" : "メンバーリストの取得中にエラーが発生しました",
     "Loading contacts …" : "連絡先を読み込み中...",
     "There are no contacts yet" : "連絡先はまだありません",
     "Create contact" : "連絡先を作成",
+    "There are no contacts in this group" : "このグループには連絡先がありません",
     "Create contacts" : "連絡先を作成",
     "Add contacts" : "連絡先を追加",
     "Loading …" : "読み込み中…",
+    "Add member" : "メンバーの追加",
+    "Leave circle" : "サークルを退会する",
+    "Delete circle" : "サークルを削除",
     "Download" : "ダウンロード",
     "Groups" : "グループ",
     "Create a new group" : "新規グループを作成",
     "Group name" : "グループ名",
+    "Circles" : "サークル",
+    "Create a new circle" : "新しいサークルを作成する",
+    "Show all groups" : "すべてのグループを表示",
+    "Collapse groups" : "グループを折りたたむ",
+    "Show all circles" : "すべてのサークルを表示",
+    "Collapse circles" : "サークルを折りたたむ",
     "This group already exists" : "このグループはすでに存在しています",
+    "This circle already exists" : "このサークルはすでに存在します",
+    "An error happened during the creation of the circle" : "サークルの作成中にエラーが発生しました",
     "Rename" : "名前を変更",
     "Enabled" : "有効",
-    "Disabled" : "無効",
     "Delete" : "削除",
     "Copied" : "コピーしました",
+    "Cannot copy" : "コピーできません",
     "Copy link" : "リンクをコピー",
     "Toggling of address book was not successful" : "アドレス帳の切り替えに失敗",
     "This will delete the address book and every contacts within it" : "これはアドレス帳とその中のすべての連絡先を削除します",
+    "Delete {addressbook}?" : "{addressbook} を削除しますか？",
     "Deletion of address book was not successful." : "アドレス帳の削除に失敗しました。",
     "Renaming of address book was not successful." : "アドレス帳の名前変更に失敗しました。",
     "_Shared with {num} entity_::_Shared with {num} entities_" : ["{num} 個のエンティティと共有"],
@@ -36,9 +55,12 @@ OC.L10N.register(
     "Unable to delete the share" : "共有を削除できません",
     "Unable to change permissions" : "権限を変更できません。",
     "Import contacts" : "連絡先のインポート",
+    "Import into the {addressbookName} address book" : "アドレス帳 {addressbookName} にインポートします",
     "Select local file" : "ローカルファイルの選択",
+    "Import from Files" : "ファイルからインポート",
     "Importing is disabled because there are no address books available" : "使用可能なアドレス帳がないため、インポートは無効です",
     "Choose a vCard file to import" : "インポートするvCardファイルを選択",
+    "Add new address book" : "新しいアドレス帳を追加する",
     "An error occurred, unable to create the address book" : "エラーが発生し、アドレス帳を作成できませんでした。",
     "First name" : "名",
     "Last name" : "姓",
@@ -48,6 +70,17 @@ OC.L10N.register(
     "Last modified" : "最終更新日",
     "Sort by {sorting}" : "{sorting} で整列",
     "Update avatars from social media" : "SNSでアバターをアップデート",
+    "(refreshed once per week)" : "(週に1回更新)",
+    "Address books" : "アドレス帳",
+    "An error happened during the config change" : "構成の変更中にエラーが発生しました",
+    "Circle name" : "サークル名",
+    "Circle owned by {owner}" : "{owner}が所有しているサークル",
+    "Request to join" : "参加リクエスト",
+    "Description" : "詳細",
+    "There is no description for this circle" : "このサークルについての説明はありません",
+    "Enter a description for the circle" : "サークルについて説明を入力してください",
+    "An error happened during description sync" : "説明の同期中にエラーが発生しました",
+    "An error happened during name sync" : "名前の同期中にエラーが発生しました",
     "Add new property" : "新しいプロパティを追加する",
     "Choose property type" : "プロパティの種類を選択",
     "Upload a new picture" : "新しい写真をアップロードする",
@@ -82,24 +115,79 @@ OC.L10N.register(
     "Unable to retrieve the contact from the server, please check your network connection." : "サーバーから連絡先を取得できないので、ネットワークの接続をご確認ください。",
     "An error occurred while trying to move the contact" : "連絡先の移動中にエラーが発生しました",
     "An error occurred while trying to copy the contact" : "連絡先のコピー中にエラーが発生しました",
+    "Add to {group}" : "{group}に追加",
     "Remove {type}" : "{type} を削除",
+    "Search {types}" : "{types} を検索",
+    "Search for people to add" : "追加するメンバーを検索",
     "No results" : "該当なし",
     "Add to group" : "グループに追加",
+    "Add {type}" : "{type}を追加",
+    "New circle name" : "新しいサークル名",
+    "Personal circle" : "パーソナルサークル",
+    "This circle will only be visible to you. Other members will not be able to see or use it." : "このサークルはあなただけに表示されます。他のメンバーはそれを見たり使用したりすることはできません。",
+    "Local circle" : "ローカルサークル",
+    "This circle will not be shared with the other instances of the global scale" : "このサークルは、グローバルスケールの他のインスタンスと共有されません",
+    "Create circle" : "サークルを作成",
+    "Loading members list …" : "メンバーリストを読み込んでいます…",
+    "The list of members is only visible to members of this circle" : "メンバーのリストは、このサークルのメンバーにのみ表示されます",
+    "There is no member in this circle" : "このサークルにはメンバーがいません",
+    "Add members" : "メンバーの追加",
+    "Show circle details" : "サークル詳細を表示",
+    "Add to {circle}" : "{circle} に追加",
+    "Unable to get the recommendations list" : "おすすめリストを取得できません",
+    "Unable to get the results" : "結果を取得できません",
+    "Some members could not be added" : "一部のメンバーを追加できませんでした",
+    "There was an issue adding members to the circle" : "サークルにメンバーを追加する際に問題が発生しました",
+    "Accept membership request" : "メンバーシップリクエストを受け入れる",
+    "Reject membership request" : "メンバーシップリクエストを拒否",
+    "Manage level" : "レベルを管理",
+    "Remove member" : "メンバーを削除",
+    "Pending" : "保留中",
+    "Promote to {level}" : "{level}に昇格",
+    "Demote to {level}" : "{level}に降格",
+    "Could not delete the member {displayName}" : "メンバー{displayName}を削除できませんでした",
+    "Could not change the member level to {level}" : "メンバーレベルを{level}に変更できませんでした",
     "Select type" : "タイプを選択",
     "Select Date" : "日付を選択",
     "Add contact in group" : "グループに連絡先を追加",
     "Select option" : "オプションを選択",
     "Unable to create the contact." : "連絡先を追加できません。",
     "Contact not found" : "連絡先がありません",
+    "Group {group} not found" : "グループ {group} が見つかりません",
     "Close" : "閉じる",
     "_{count} error_::_{count} errors_" : ["{count} つのエラー"],
     "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["{アドレス帳}に %n の連絡先をインポートしています。"],
     "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["{アドレス帳}に %n 連絡先のインポートが完了しました"],
     "Import" : "インポート",
+    "Could not copy" : "コピーできませんでした",
+    "Join circle" : "サークルに参加",
+    "You are about to leave {circle}.\nAre you sure?" : "{circle}を離れようとしています。\nよろしいですか？",
+    "Please confirm circle leave" : "サークルから退会しますか",
+    "Could not leave the circle {displayName}" : "サークル{displayName}を退会できませんでした",
+    "Unable to join the circle" : "サークルに参加できません",
+    "You are about to delete {circle}.\nAre you sure?" : "{circle}を削除しようとしています。\nよろしいですか？",
+    "Please confirm circle deletion" : "サークルの削除しますか",
+    "Unable to delete the circle" : "サークルを削除できません",
+    "Link copied to the clipboard" : "クリップボードにリンクをコピーしました",
+    "Could not copy link to the clipboard." : "クリップボードにコピーできませんでした",
     "Not grouped" : "グループ化されていません",
     "Recently contacted" : "最近連絡した",
+    "Circles allow you to create groups with other users on a Nextcloud instance and share with them." : "サークルを使用すると、Nextcloudで他のユーザーとグループを作成し、それらと共有できます。",
+    "Circle" : "サークル",
+    "User" : "ユーザー",
+    "Group" : "グループ",
     "Email" : "メール",
     "Contact" : "連絡先",
+    "Member" : "メンバー",
+    "Moderator" : "モデレータ",
+    "Admin" : "管理者",
+    "Owner" : "所有者",
+    "Invites" : "招待",
+    "Anyone can request membership" : "誰でもメンバーへの参加をリクエストできます",
+    "Visibility" : "公開レベル",
+    "Visible to everyone" : "すべての人に公開",
+    "Users" : "ユーザー",
+    "Emails" : "メール",
     "Nickname" : "ニックネーム",
     "Detailed name" : "詳細名",
     "Additional names" : "ミドルネーム",
@@ -112,11 +200,11 @@ OC.L10N.register(
     "Home" : "自宅",
     "Work" : "職場",
     "Other" : "その他",
-    "Address" : "アドレス",
-    "Post office box" : "私書箱",
+    "Address" : "住所",
+    "Post office box" : "郵便ポスト",
     "Extended address" : "拡張アドレス",
     "City" : "市町村",
-    "State or province" : "州／県",
+    "State or province" : "都道府県",
     "Postal code" : "郵便番号",
     "Country" : "国名",
     "Birthday" : "誕生日",
@@ -148,6 +236,7 @@ OC.L10N.register(
     "Colleague" : "同僚",
     "Manager" : "マネージャー",
     "Assistant" : "アシスタント",
+    "Related contacts" : "関連した連絡先",
     "Agent" : "エージェント",
     "Emergency" : "緊急",
     "Co-worker" : "同僚",
@@ -156,10 +245,12 @@ OC.L10N.register(
     "Male" : "男性",
     "None" : "なし",
     "Unknown" : "不明",
+    "Time zone" : "時間帯",
     "Spoken languages" : "話せる言語",
     "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed}連絡先の読み込みができませんでした。"],
-    "Unable to delete contact" : "連絡先を削除できません。",
-    "Your web browser is out of date" : "Webブラウザーが古いです",
-    "This application is not compatible with Internet Explorer" : "このアプリはInternet Explorerと互換性がありません"
+    "Some circle(s) an error occurred. Check the console for more details." : "一部のサークルでエラーが発生しました。詳細については、コンソールを確認してください。",
+    "Unable to create circle {circleName}" : "サークル {circleName} を作成できません",
+    "Unable to delete circle {circleId}" : "サークル{circleId}を削除できません",
+    "Unable to delete contact" : "連絡先を削除できません。"
 },
 "nplurals=1; plural=0;");
