@@ -10,12 +10,10 @@ OC.L10N.register(
     "Group name" : "ჯგუფის სახელი",
     "Rename" : "სახელის შეცვლა",
     "Enabled" : "მოქმედია",
-    "Disabled" : "არაა მოქმედი",
     "Delete" : "გაუქმება",
     "Copy link" : "ბმულის კოპირება",
     "Share with users or groups" : "გაზიარება მოხმარებლებთან ან ჯგუფებთან",
     "can edit" : "შეუძლია შეცვლა",
-    "Address book name" : "მისამართების წიგნის სახელი",
     "First name" : "სახელი",
     "Last name" : "გვარი",
     "Display name" : "დისპლეი სახელი",
