@@ -4,28 +4,42 @@ OC.L10N.register(
     "Details" : "Дэлгэрэнгүй",
     "All contacts" : "Бүх харилцагчид",
     "Contacts" : "Харилцагчид",
+    "Copy to full name" : "Бүтэн нэр хуулах",
+    "Loading …" : "Уншиж байна...",
+    "Add member" : "Гишүүн нэмэх",
     "Download" : "Татаж авах",
     "Groups" : "Багууд",
     "Group name" : "Бүлгийн нэр",
     "Rename" : "Нэр солих",
     "Enabled" : "Идэвхижүүлэх",
-    "Disabled" : "идэвхигүй",
     "Delete" : "Устгах",
+    "Copied" : "Хуулагдсан",
+    "Cannot copy" : "Хуулагдаагүй",
+    "Copy link" : "Холбоос хуулах",
     "Share with users or groups" : "Бусдад түгээх",
     "can edit" : "засаж чадна",
     "First name" : "Нэр",
     "Last name" : "Овог",
     "Display name" : "Харагдах нэр",
     "Last modified" : "Сүүлд өөрчилсөн",
+    "Description" : "Тайлбар",
+    "Upload a new picture" : "Шинэ зураг оруулах",
+    "Choose from Files" : "Файлаас сонгох",
+    "Download picture" : "Зураг татаж авах",
+    "Delete picture" : "Зураг устгах",
     "Invalid image" : "буруу зураг",
+    "Image is too big (max 1MB)." : "Зургийн хэмжээ их /max 1MB/",
     "Name" : "Нэр",
     "Title" : "Цол/Албан тушаал",
+    "Select address book" : "Хаягийн бүртгэл сонгох",
     "Cancel" : "болиулах",
+    "Address book" : "Хаягийн бүртгэл",
     "New contact" : "Шинэ харилцагч",
     "No results" : "Үр дүн байхгүй",
     "Close" : "Хаах",
     "Import" : "Импорт",
     "Not grouped" : "Багт ороогүй",
+    "User" : "Хэрэглэгч",
     "Email" : "Цахим шуудан",
     "Nickname" : "Товч нэр",
     "Detailed name" : "Дэлгэрэнгүй нэр",
@@ -50,8 +64,21 @@ OC.L10N.register(
     "Fax home" : "Гэрийн факс",
     "Fax work" : "Ажлын факс",
     "Social network" : "Олон нийтийн сүлжээ",
+    "Child" : "хүүхэд",
+    "Mother" : "эх",
+    "Father" : "эцэг",
+    "Parent" : "эцэг эх",
+    "Brother" : "ах",
+    "Sister" : "эгч",
     "Relative" : "Хамаарал",
+    "Friend" : "Найз",
+    "Manager" : "Менежер",
+    "Co-worker" : "Хамтран ажиллагч",
+    "Gender" : "Хүйс",
+    "Female" : "Эмэгтэй",
+    "Male" : "Эрэгтэй",
     "None" : "юу ч үгүй",
-    "Unknown" : "Үл танигдах зүйл"
+    "Unknown" : "Үл танигдах зүйл",
+    "Time zone" : "Цагийн бүс"
 },
 "nplurals=2; plural=(n != 1);");
