@@ -1,21 +1,21 @@
 OC.L10N.register(
     "contacts",
     {
+    "Download" : "ڈاؤن لوڈ",
+    "Group name" : "گروپ نام",
+    "Rename" : "Rename",
+    "Delete" : "حذف کریں",
+    "can edit" : "تبدیل کر سکے ھیں",
     "Invalid image" : "غلط تصویر",
     "Name" : "اسم",
     "Title" : "عنوان",
-    "Download" : "ڈاؤن لوڈ",
-    "Delete" : "حذف کریں",
     "Cancel" : "منسوخ کریں",
-    "Rename" : "Rename",
-    "can edit" : "تبدیل کر سکے ھیں",
-    "Group name" : "گروپ نام",
     "Close" : "بند ",
+    "Email" : "email",
     "Notes" : "Notes",
     "Location" : "مقام",
     "Work" : "کام",
     "Other" : "دیگر",
-    "Birthday" : "سالگرہ",
-    "Email" : "email"
+    "Birthday" : "سالگرہ"
 },
 "nplurals=2; plural=(n != 1);");
