@@ -25,6 +25,7 @@ OC.L10N.register(
     "Leave circle" : "離開小圈圈",
     "Delete circle" : "刪除小圈圈",
     "Download" : "下載",
+    "Send email" : "傳送電子郵件",
     "Groups" : "群組",
     "Create a new group" : "建立新群組",
     "Group name" : "群組名稱",
@@ -39,7 +40,6 @@ OC.L10N.register(
     "An error happened during the creation of the circle" : "建立小圈圈時發生錯誤",
     "Rename" : "重新命名",
     "Enabled" : "已啟用",
-    "Disabled" : "已停用",
     "Delete" : "刪除",
     "Copied" : "已複製",
     "Cannot copy" : "無法複製",
@@ -263,8 +263,6 @@ OC.L10N.register(
     "Some circle(s) an error occurred. Check the console for more details." : "部份小圈圈發生錯誤。請檢查主控台以取得更多資訊。",
     "Unable to create circle {circleName}" : "無法建立小圈圈 {circleName}",
     "Unable to delete circle {circleId}" : "無法刪除小圈圈 {circleId}",
-    "Unable to delete contact" : "無法刪除聯絡人",
-    "Your web browser is out of date" : "您的網路瀏覽器已過期",
-    "This application is not compatible with Internet Explorer" : "此應用程式與 Internet Explorer 不相容"
+    "Unable to delete contact" : "無法刪除聯絡人"
 },
 "nplurals=1; plural=0;");
